@@ -24,9 +24,10 @@ except ImportError:  # pragma: no cover
     from jinja2 import contextfilter as pass_context  # type: ignore
 
 from jinja2.runtime import Context
+import markdown2
 from markupsafe import Markup
 
-import pdoc.markdown2
+import pdoc
 
 from . import docstrings
 
@@ -61,7 +62,7 @@ markdown_extensions = {
     "cuddled-lists": None,
     "fenced-code-blocks": {"cssclass": formatter.cssclass},
     "footnotes": None,
-    "header-ids": None,
+    "header-ids": {"mixed": True, "prefix": None, "reset-count": True},
     "link-patterns": None,
     "markdown-in-html": None,
     "mermaid": None,
@@ -99,7 +100,7 @@ Link pattern used for markdown2's [`link-patterns` extra](https://github.com/tre
 
 
 @cache
-def highlight(doc: pdoc.doc.Doc) -> str:
+def highlight(doc: pdoc.doc.Doc) -> Markup:
     """Highlight the source code of a documentation object using pygments."""
     if isinstance(doc, str):  # pragma: no cover
         warnings.warn(
@@ -114,7 +115,7 @@ def highlight(doc: pdoc.doc.Doc) -> str:
     return Markup(pygments.highlight(doc.source, lexer, formatter))
 
 
-def format_signature(sig: inspect.Signature, colon: bool) -> str:
+def format_signature(sig: inspect.Signature, colon: bool) -> Markup:
     """Format and highlight a function signature using pygments. Returns HTML."""
     # First get a list with all params as strings.
     result = pdoc.doc._PrettySignature._params(sig)  # type: ignore
@@ -175,7 +176,7 @@ def to_html(docstring: str) -> str:
     # careful: markdown2 returns a subclass of str with an extra
     # .toc_html attribute. don't further process the result,
     # otherwise this attribute will be lost.
-    return pdoc.markdown2.markdown(  # type: ignore
+    return markdown2.markdown(  # type: ignore
         docstring,
         extras=markdown_extensions,
         link_patterns=markdown_link_patterns,
@@ -308,7 +309,7 @@ def module_candidates(identifier: str, current_module: str) -> Iterable[str]:
 @pass_context
 def linkify(
     context: Context, code: str, namespace: str = "", shorten: bool = True
-) -> str:
+) -> Markup:
     """
     Link all identifiers in a block of text. Identifiers referencing unknown modules or modules that
     are not rendered at the moment will be ignored.
@@ -408,7 +409,7 @@ def linkify(
             # First part of the identifier (e.g. "foo") - this is optional for relative references.
             (?:
                 \b
-                (?!\d)[a-zA-Z0-9_]+
+                (?!\d)\w+
                 |
                 \.*  # We may also start with multiple dots.
             )
@@ -416,7 +417,7 @@ def linkify(
             (?:
                 # A single dot or a dot surrounded with pygments highlighting.
                 (?:\.|</span><span\ class="o">\.</span><span\ class="n">)
-                (?!\d)[a-zA-Z0-9_]+
+                (?!\d)\w+
             )+
             (?:\(\)|\b(?!\(\)))  # we either end on () or on a word boundary.
             (?!</a>)  # not an existing link
@@ -424,7 +425,7 @@ def linkify(
 
             | # Part 2: `foo` or `foo()`. `foo.bar` is already covered with part 1.
             (?<=<code>)
-                 (?!\d)[a-zA-Z0-9_]+
+                 (?!\d)\w+
             (?:\(\))?
             (?=</code>(?!</a>))
             """,
@@ -436,7 +437,7 @@ def linkify(
 
 
 @pass_context
-def link(context: Context, spec: tuple[str, str], text: str | None = None) -> str:
+def link(context: Context, spec: tuple[str, str], text: str | None = None) -> Markup:
     """Create a link for a specific `(modulename, qualname)` tuple."""
     mod: pdoc.doc.Module = context["module"]
     modulename, qualname = spec
@@ -469,7 +470,7 @@ def link(context: Context, spec: tuple[str, str], text: str | None = None) -> st
         return Markup(
             f'<a href="{relative_link(context["module"].modulename, modulename)}{qualname}">{text or fullname}</a>'
         )
-    return text or fullname
+    return Markup.escape(text or fullname)
 
 
 def edit_url(
@@ -507,7 +508,7 @@ def root_module_name(all_modules: Mapping[str, pdoc.doc.Module]) -> str | None:
         return None
 
 
-def minify_css(css: str) -> str:
+def minify_css(css: str) -> Markup:
     """Do some very basic CSS minification."""
     css = re.sub(r"[ ]{4}|\n|(?<=[:{}]) | (?=[{}])", "", css)
     css = re.sub(
