@@ -5,10 +5,6 @@ class MyDict(dict):
     pass
 
 
-class CustomException(RuntimeError):
-    """custom exception type"""
-
-
 @deprecated("Do not use this anymore")
 def deprecated_func():
     pass
