@@ -3,4 +3,4 @@ from __future__ import annotations
 import typing
 
 if typing.TYPE_CHECKING:
-    StrOrInt: typing.TypeAlias = "typing.Union[str, int]"
+    StrOrInt: typing.TypeAlias = "str | int"
