@@ -3,4 +3,4 @@ from __future__ import annotations
 import typing
 
 if typing.TYPE_CHECKING:
-    StrOrBool: typing.TypeAlias = "typing.Union[str, bool]"
+    StrOrBool: typing.TypeAlias = "str | bool"
